- name: "reply_prompt"
  content: |
    {% if settings.reply_prompt_prefix %}
      {%- set prompt_parts = reply_prompt.split(":", 1) -%}
      {%- if prompt_parts|length > 1 and prompt_parts[1].lstrip() -%}
        {%- set prompt_suffix = "\\n" + prompt_parts[1].lstrip() -%}
      {%- else -%}
        {%- set prompt_suffix = "\\n" -%}
      {%- endif -%}
      {{ settings.start_token }}{{ escape_special_characters(prompt_parts[0] + ": " + settings.reply_prompt_prefix + prompt_suffix) }}
    {% else %}
      {{ settings.start_token }}{{ escape_special_characters(reply_prompt) }}
    {% endif %}

{% if "heather_voice" in model_id %}
- name: "special audio token"
  content: |
    {{ settings.audio_mode_token }}
{% endif %}
